@@ -4,24 +4,24 @@ from enum import Enum
 
 
 class OnOff(Enum):
-    OFF = 0,
+    OFF = 0
     ON = 1
 
 
 class MachineOperationMode(Enum):
-    STOP = 0,
-    COLD = 1,
-    HOT = 2,
-    AIR = 3,
+    STOP = 0
+    COLD = 1
+    HOT = 2
+    AIR = 3
     HOTPLUS = 258
 
 
 class ZoneMode(Enum):
-    STOP = 0,
-    COLD = 1,
-    HOT_AIR = 2,
-    AIR = 3,
-    FLOOT_HOT = 4,
+    STOP = 0
+    COLD = 1
+    HOT_AIR = 2
+    AIR = 3
+    FLOOT_HOT = 4
     HOTPLUS = 5
 
 
@@ -48,33 +48,33 @@ class LastGridCloseMode(Enum):
 
 
 class GridMode(Enum):
-    All_NONE = 0,
+    All_NONE = 0
     PROPORTIONAL = 1
 
 
 class GridAngle(Enum):
-    NINETY = 0,
-    FIFTY = 1,
-    FOURTY_FIVE = 2,
+    NINETY = 0
+    FIFTY = 1
+    FOURTY_FIVE = 2
     FOURTY = 3
 
 
 class ProbeType(Enum):
-    NO_PROBE = 0,
-    REMOTE = 1,
+    NO_PROBE = 0
+    REMOTE = 1
     FLOOR = 2
 
 
 class RelayConfig(Enum):
-    OFF = 0,
-    USUALLY_OPEN = 1,
+    OFF = 0
+    USUALLY_OPEN = 1
     USUALLY_CLOSE = 2
 
 
 class LocalFancoilType(Enum):
-    GRID = 0,
-    FANCOIL = 1,
-    
+    GRID = 0
+    FANCOIL = 1
+
 def state_value(state, address, init = 0, end = 15):
     return shifting(pad_right_list(bitfield(state[address]),16,0)[init:end+1])
 
